@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Dist::Zilla::App::Command::authordeps;
 BEGIN {
-  $Dist::Zilla::App::Command::authordeps::VERSION = '4.200000';
+  $Dist::Zilla::App::Command::authordeps::VERSION = '4.200009';
 }
 use Dist::Zilla::App -command;
 # ABSTRACT: List your distribution's author dependencies
@@ -15,6 +15,7 @@ use Config::INI::Reader;
 
 use namespace::autoclean;
 
+
 sub abstract { "list your distribution's author dependencies" }
 
 sub opt_spec {
@@ -55,13 +56,37 @@ sub extract_author_deps {
   my $fh     = $ini->openr;
   my $config = Config::INI::Reader->read_handle($fh);
 
-  my @sections = uniq map  { s/\s.*//; $_ }
-                      grep { $_ ne '_' }
-                      keys %{$config};
+  my @packages =
+    uniq
+    map  {; Dist::Zilla::Util->expand_config_package_name($_) }
+    map  { s/\s.*//; $_ }
+    grep { $_ ne '_' }
+    keys %$config;
+
+  seek $fh, 0, 0;
+
+  while (<$fh>) {
+    chomp;
+    next unless /\A\s*;\s*authordep\s*(\S+)\s*\z/;
+    push @packages, $1;
+  }
+
+  seek $fh, 0, 0;
+
+  my $in_filter = 0;
+  while (<$fh>) {
+    next unless $in_filter or /^\[\s*\@Filter/;
+    $in_filter = 0, next if /^\[/ and ! /^\[\s*\@Filter/;
+    $in_filter = 1;
+
+    next unless /\A-bundle\s*=\s*([^;]+)/;
+    push @packages, Dist::Zilla::Util->expand_config_package_name($1);
+  }
 
   return
+    grep { !/^inc::/ }
     grep { $missing ? (! eval "require $_; 1;") : 1 }
-    map {; Dist::Zilla::Util->expand_config_package_name($_) } @sections;
+    @packages;
 }
 
 1;
@@ -75,7 +100,18 @@ Dist::Zilla::App::Command::authordeps - List your distribution's author dependen
 
 =head1 VERSION
 
-version 4.200000
+version 4.200009
+
+=head1 SYNOPSIS
+
+  $ dzil authordeps
+
+This will scan the F<dist.ini> file and print a list of plugin modules that
+probably need to be installed for the dist to be buildable.  This is a very
+naive scan, but tends to be pretty accurate.  Modules can be added to its
+results by using special comments in the form:
+
+  ; authordep Some::Package
 
 =head1 AUTHOR
 
@@ -83,7 +119,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2011 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
