@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Dist::Zilla::App::Command::run;
 BEGIN {
-  $Dist::Zilla::App::Command::run::VERSION = '4.200000';
+  $Dist::Zilla::App::Command::run::VERSION = '4.200009';
 }
 # ABSTRACT: run stuff in a dir where your dist is built
 
@@ -12,9 +12,15 @@ use Moose::Autobox;
 
 sub abstract { 'run stuff in a dir where your dist is built' }
 
+sub usage_desc {
+  return '%c %o run command [ arg1 arg2 ... ]';
+}
+
 sub execute {
   my ($self, $opts, $args) = @_;
 
+  $self->usage_error("no command to run supplied!") unless @$args;
+
   $self->zilla->run_in_build($args);
 }
 
@@ -29,7 +35,7 @@ Dist::Zilla::App::Command::run - run stuff in a dir where your dist is built
 
 =head1 VERSION
 
-version 4.200000
+version 4.200009
 
 =head1 SYNOPSIS
 
@@ -64,7 +70,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2011 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
