@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::PkgVersion;
 BEGIN {
-  $Dist::Zilla::Plugin::PkgVersion::VERSION = '4.101900';
+  $Dist::Zilla::Plugin::PkgVersion::VERSION = '4.200009';
 }
 # ABSTRACT: add a $VERSION to your packages
 use Moose;
@@ -12,6 +12,9 @@ with(
 );
 
 use PPI;
+use MooseX::Types::Perl qw(LaxVersionStr);
+
+use namespace::autoclean;
 
 
 sub munge_files {
@@ -36,7 +39,9 @@ sub munge_perl {
   my ($self, $file) = @_;
 
   my $version = $self->zilla->version;
-  Carp::croak("invalid characters in version") if $version !~ /\A[.0-9_]+\z/;
+
+  Carp::croak("invalid characters in version")
+    unless LaxVersionStr->check($version);
 
   my $content = $file->content;
 
@@ -67,15 +72,16 @@ sub munge_perl {
       next;
     }
 
-    if ($stmt->content =~ /package\s*\n\s*\Q$package/) {
-      $self->log([ 'skipping private package %s', $package ]);
+    if ($stmt->content =~ /package\s*(?:#.*)?\n\s*\Q$package/) {
+      $self->log([ 'skipping private package %s in %s', $package, $file->name ]);
       next;
     }
 
     # the \x20 hack is here so that when we scan *this* document we don't find
     # an assignment to version; it shouldn't be needed, but it's been annoying
     # enough in the past that I'm keeping it here until tests are better
-    my $perl = "BEGIN {\n  \$$package\::VERSION\x20=\x20'$version';\n}\n";
+    my $trial = $self->zilla->is_trial ? ' # TRIAL' : '';
+    my $perl = "BEGIN {\n  \$$package\::VERSION\x20=\x20'$version';$trial\n}\n";
 
     my $version_doc = PPI::Document->new(\$perl);
     my @children = $version_doc->schildren;
@@ -107,14 +113,26 @@ Dist::Zilla::Plugin::PkgVersion - add a $VERSION to your packages
 
 =head1 VERSION
 
-version 4.101900
+version 4.200009
+
+=head1 SYNOPSIS
+
+in dist.ini
+
+  [PkgVersion]
 
 =head1 DESCRIPTION
 
-This plugin will add a line like the following to each package in each Perl
+This plugin will add lines like the following to each package in each Perl
 module or program (more or less) within the distribution:
 
-  our $VERSION = 0.001; # where 0.001 is the version of the dist
+  BEGIN {
+    $MyModule::VERSION = 0.001;
+  }
+
+...where 0.001 is the version of the dist, and MyModule is the name of the
+package being given a version.  (In other words, it always uses fully-qualified
+names to assign versions.)
 
 It will skip any package declaration that includes a newline between the
 C<package> keyword and the package name, like:
@@ -131,7 +149,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2011 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
