@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::Prereqs;
 BEGIN {
-  $Dist::Zilla::Plugin::Prereqs::VERSION = '4.101900';
+  $Dist::Zilla::Plugin::Prereqs::VERSION = '4.200009';
 }
 # ABSTRACT: list simple prerequisites
 use Moose;
@@ -13,9 +13,10 @@ sub __from_name {
 
   # such as C<configure>, C<build>, C<test> and C<runtime>.  Values are
   # relationship such as C<requires>, C<prefers>, or C<recommends>.  The
+  # phase component is optional and will default to Runtime.
 
   my ($phase, $type) = $name =~ /\A
-    (Build|Test|Runtime|Configure|Develop)
+    (Build|Test|Runtime|Configure|Develop)?
     (Requires|Recommends|Suggests|Conflicts)
   \z/x;
 
@@ -109,7 +110,7 @@ sub register_prereqs {
 }
 
 no Moose;
-__PACKAGE__->meta->make_immutable(inline_constructor => 0);
+__PACKAGE__->meta->make_immutable;
 1;
 
 __END__
@@ -121,7 +122,7 @@ Dist::Zilla::Plugin::Prereqs - list simple prerequisites
 
 =head1 VERSION
 
-version 4.101900
+version 4.200009
 
 =head1 SYNOPSIS
 
@@ -201,6 +202,9 @@ conflicts
 
 =back
 
+If the phase is omitted, it will default to I<runtime>; thus, specifying
+"Prereqs / Recommends" in your dist.ini is equivalent to I<RuntimeRecommends>.
+
 Not all of these phases are useful for all tools, especially tools that only
 understand version 1.x CPAN::Meta files.
 
@@ -210,7 +214,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2011 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
