@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::TestRelease;
 BEGIN {
-  $Dist::Zilla::Plugin::TestRelease::VERSION = '4.200000';
+  $Dist::Zilla::Plugin::TestRelease::VERSION = '4.200009';
 }
 use Moose;
 with 'Dist::Zilla::Role::BeforeRelease';
@@ -35,6 +35,7 @@ sub before_release {
   my $target = $tmpdir->subdir( $self->zilla->built_in->dir_list(-1) );
 
   local $ENV{RELEASE_TESTING} = 1;
+  local $ENV{AUTHOR_TESTING} = 1;
   $self->zilla->run_tests_in($target);
 
   $self->log("all's well; removing $tmpdir");
@@ -54,7 +55,7 @@ Dist::Zilla::Plugin::TestRelease - extract archive and run tests before releasin
 
 =head1 VERSION
 
-version 4.200000
+version 4.200009
 
 =head1 DESCRIPTION
 
@@ -64,6 +65,9 @@ tests.  If the tests fail, the release is aborted and the temporary directory
 is left in place.  If the tests pass, the temporary directory is cleaned up and
 the release process continues.
 
+This will set the RELEASE_TESTING and AUTHOR_TESTING env vars while running the
+testsuite.
+
 =head1 CREDITS
 
 This plugin was originally contributed by Christopher J. Madsen.
@@ -74,7 +78,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2011 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
